@@ -1,4 +1,4 @@
-use number_traits::{Num, Radical};
+use number_traits::{Num, Sqrt};
 use div::sdiv;
 
 
@@ -12,7 +12,7 @@ fn test_length_values_sq() {
 }
 
 #[inline]
-pub fn length_values<'a, 'b, T: Copy + Num + Radical>(x: T, y: T) -> T {
+pub fn length_values<'a, 'b, T: Copy + Num + Sqrt>(x: T, y: T) -> T {
     let lsq = length_values_sq(x, y);
     if lsq == T::zero() {lsq} else {lsq.sqrt()}
 }
@@ -22,7 +22,7 @@ fn test_length_values() {
 }
 
 #[inline]
-pub fn inv_length_values<'a, 'b, T: Copy + Num + Radical>(x: T, y: T) -> T {
+pub fn inv_length_values<'a, 'b, T: Copy + Num + Sqrt>(x: T, y: T) -> T {
     let lsq = length_values_sq(x, y);
     if lsq == T::zero() {lsq} else {T::one() / lsq.sqrt()}
 }
@@ -50,7 +50,7 @@ fn test_cross() {
 }
 
 #[inline]
-pub fn length_sq<'a, T: Copy + Num + Radical>(out: &'a [T; 2]) -> T {
+pub fn length_sq<'a, T: Copy + Num + Sqrt>(out: &'a [T; 2]) -> T {
     length_values_sq(out[0], out[1])
 }
 #[test]
@@ -59,7 +59,7 @@ fn test_length_sq() {
 }
 
 #[inline]
-pub fn length<'a, T: Copy + Num + Radical>(out: &'a [T; 2]) -> T {
+pub fn length<'a, T: Copy + Num + Sqrt>(out: &'a [T; 2]) -> T {
     length_values(out[0], out[1])
 }
 #[test]
@@ -68,7 +68,7 @@ fn test_length() {
 }
 
 #[inline]
-pub fn normalize<'a, 'b, T: Copy + Num + Radical>(out: &'a mut [T; 2], a: &'b [T; 2]) -> &'a mut [T; 2] {
+pub fn normalize<'a, 'b, T: Copy + Num + Sqrt>(out: &'a mut [T; 2], a: &'b [T; 2]) -> &'a mut [T; 2] {
     sdiv(out, a, length(a))
 }
 #[test]
